@@ -20,6 +20,7 @@
 
 from __future__ import print_function
 from __future__ import absolute_import
+from __future__ import division
 
 import glob
 import hashlib
@@ -33,6 +34,8 @@ import pkgutil
 import sys
 import tempfile
 
+import six
+
 from vdsm.common import commands
 from vdsm.common import exception
 from vdsm.common.constants import P_VDSM_HOOKS, P_VDSM_RUN
@@ -61,6 +64,8 @@ _JSON_HOOK = 2
 
 def _runHooksDir(data, dir, vmconf={}, raiseError=True, errors=None, params={},
                  hookType=_DOMXML_HOOK):
+    if errors is None:
+        errors = []
 
     scripts = _scriptsPerDir(dir)
     scripts.sort()
@@ -79,8 +84,8 @@ def _runHooksDir(data, dir, vmconf={}, raiseError=True, errors=None, params={},
         scriptenv = os.environ.copy()
 
         # Update the environment using params and custom configuration
-        env_update = [params.iteritems(),
-                      vmconf.get('custom', {}).iteritems()]
+        env_update = [six.iteritems(params),
+                      six.iteritems(vmconf.get('custom', {}))]
 
         # Encode custom properties to UTF-8 and save them to scriptenv
         # Pass str objects (byte-strings) without any conversion
@@ -103,22 +108,19 @@ def _runHooksDir(data, dir, vmconf={}, raiseError=True, errors=None, params={},
         elif hookType == _JSON_HOOK:
             scriptenv['_hook_json'] = data_filename
 
-        errorSeen = False
         for s in scripts:
             rc, out, err = commands.execCmd([s], raw=True,
                                             env=scriptenv)
             logging.info('%s: rc=%s err=%s', s, rc, err)
             if rc != 0:
-                errorSeen = True
-                if errors is not None:
-                    errors.append(err)
+                errors.append(err)
 
             if rc == 2:
                 break
             elif rc > 2:
                 logging.warn('hook returned unexpected return code %s', rc)
 
-        if errorSeen and raiseError:
+        if errors and raiseError:
             raise exception.HookError(err)
 
         with open(data_filename) as f:
@@ -157,7 +159,7 @@ def before_vm_start(domxml, vmconf={}, final_callback=None):
                              raiseError=False, errors=errors)
     if final_callback is not None:
         final_callback(final_xml)
-    if len(errors) > 0:
+    if errors:
         raise exception.HookError(errors[-1])
     return final_xml
 
