@@ -30,6 +30,7 @@ This module provides needed interfaces to for attaching and detaching volumes:
 from __future__ import absolute_import
 from __future__ import division
 
+import functools
 import json
 import logging
 import os
@@ -57,28 +58,35 @@ DEV_RBD = "/dev/rbd"
 log = logging.getLogger("storage.managedvolume")
 
 
+def requires_os_brick(func):
+
+    @functools.wraps(func)
+    def wrapper(*args, **kwargs):
+        if os_brick is None:
+            raise se.ManagedVolumeNotSupported("Cannot import os_brick")
+        return func(*args, **kwargs)
+
+    return wrapper
+
+
 # Public interface
 
 
+@requires_os_brick
 def connector_info():
     """
     Get connector information from os-brick.
         If not running as root, use supervdsm to invoke this function as root.
     """
-    if os_brick is None:
-        raise se.ManagedVolumeNotSupported("Cannot import os_brick.initiator")
-
     log.debug("Starting get connector_info")
     return run_helper("connector_info")
 
 
+@requires_os_brick
 def attach_volume(vol_id, connection_info):
     """
     Attach volume with os-brick.
     """
-    if os_brick is None:
-        raise se.ManagedVolumeNotSupported("Cannot import os_brick.initiator")
-
     db = managedvolumedb.open()
     with closing(db):
         _add_volume(db, vol_id, connection_info)
@@ -105,16 +113,15 @@ def attach_volume(vol_id, connection_info):
 
     log.debug("Attached volume %s attachment=%s", vol_id, attachment)
 
-    return {"result": {'attachment': attachment, 'path': path}}
+    return {"result": {'attachment': attachment, 'path': path,
+                       'vol_id': vol_id}}
 
 
+@requires_os_brick
 def detach_volume(vol_id):
     """
     Detach volume with os-brick.
     """
-    if os_brick is None:
-        raise se.ManagedVolumeNotSupported("Cannot import os_brick.initiator")
-
     db = managedvolumedb.open()
     with closing(db):
         try:
@@ -130,6 +137,39 @@ def detach_volume(vol_id):
         db.remove_volume(vol_id)
 
 
+def volumes_info(vol_ids=()):
+    """
+    Lookup volumes information in managed volume database.
+
+    Lookup volumes info in managed volume database for all volume IDs in the
+    vol_ids list and returns a list with volume information for each volume ID
+    which is present in the database. Each record contains connection info.
+    Path and attachment info of the volume is contained only when the resource
+    is attached. Dictionary can also contain 'exists' item, which is set to
+    True if the volume is connected and to False otherwise. Empty list is
+    returned if any of IDs are not in the database.
+
+    If the list of requested volume IDs is not specified or empty, list of all
+    volumes info in the DB is returned.
+
+    Arguments:
+            vol_ids (list): list of queried volume IDs.
+
+    Returns:
+            List of managed volumes information.
+    """
+    db = managedvolumedb.open()
+    with closing(db):
+        result = []
+        for vol_info in db.iter_volumes(vol_ids):
+            if "path" in vol_info:
+                vol_info["exists"] = os.path.exists(vol_info["path"])
+            vol_info.pop("multipath_id", None)
+            result.append(vol_info)
+
+    return {"result": result}
+
+
 # supervdsm interface
 
 
