@@ -17,7 +17,9 @@
 #
 # Refer to the README and COPYING files for full details of the license
 #
+
 from __future__ import absolute_import
+from __future__ import division
 
 import tempfile
 
@@ -43,3 +45,7 @@ class TestOsinfo(VdsmTestCase):
             f.flush()
             self.assertEqual(osinfo.kernel_args(f.name),
                              expected_result)
+
+    def test_package_versions(self):
+        pkgs = osinfo.package_versions()
+        self.assertIn('kernel', pkgs)
